@@ -1,5 +1,5 @@
-/* 
- *            Copyright 2009-2018 The VOTCA Development Team
+/*
+ *            Copyright 2009-2019 The VOTCA Development Team
  *                       (http://www.votca.org)
  *
  *      Licensed under the Apache License, Version 2.0 (the "License")
@@ -18,14 +18,17 @@
  */
 
 #ifndef __VOTCA_TOOLS_EIGEN__H
-#define	__VOTCA_TOOLS_EIGEN__H
+#define __VOTCA_TOOLS_EIGEN__H
 
 #include <votca/tools/votca_config.h>
 
-
-#if defined(MKL)
+#ifdef MKL_FOUND
 #include <mkl.h>
-  #define EIGEN_USE_MKL_ALL 
+#define EIGEN_USE_MKL_ALL
+#endif
+
+#ifdef FFTW3_FOUND
+#define EIGEN_FFTW_DEFAULT
 #endif
 
 //! Macro to detect strictly gcc.
@@ -33,25 +36,21 @@
 //! However, they're also defined by Clang/LLVM and Intel compilers to indicate
 //! compatibility. This macro can be used to detect strictly gcc and not clang
 //! or icc.
-#if (defined(__GNUC__) || defined(__GNUG__)) && !(defined(__clang__) || defined(__INTEL_COMPILER))
-  #define STRICT_GNUC
-#define GCC_VERSION (__GNUC__ * 10000 \
-                     + __GNUC_MINOR__ * 100 \
-                     + __GNUC_PATCHLEVEL__)
+#if (defined(__GNUC__) || defined(__GNUG__)) && \
+    !(defined(__clang__) || defined(__INTEL_COMPILER))
+#define STRICT_GNUC
+#define GCC_VERSION \
+  (__GNUC__ * 10000 + __GNUC_MINOR__ * 100 + __GNUC_PATCHLEVEL__)
 #endif
 
-
-
-#if(defined STRICT_GNUC) && GCC_VERSION>70000
+#if (defined STRICT_GNUC) && GCC_VERSION > 70000
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wint-in-bool-context"
 #endif
-#include <Eigen/Dense>
-#if(defined STRICT_GNUC) && GCC_VERSION>70000
+#include <Eigen/Eigen>
+#include <unsupported/Eigen/CXX11/Tensor>
+#if (defined STRICT_GNUC) && GCC_VERSION > 70000
 #pragma GCC diagnostic pop
 #endif
 
-
-
-#endif	//__VOTCA_TOOLS_EIGEN__H
-
+#endif  //__VOTCA_TOOLS_EIGEN__H
