@@ -1,5 +1,5 @@
 /*
- * Copyright 2009-2018 The VOTCA Development Team (http://www.votca.org)
+ * Copyright 2009-2020 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -18,26 +18,26 @@
 #ifndef _VOTCA_TOOLS_GETLINE_H
 #define _VOTCA_TOOLS_GETLINE_H
 
+#include <algorithm>
 #include <iostream>
 #include <string>
-#include <algorithm>
 
-namespace votca { namespace tools {
-    
+namespace votca {
+namespace tools {
+
 /**
-    \brief Wrapper for a getline function 
+    \brief Wrapper for a getline function
 
     Removes Windows end-of-line character
- 
+
   */
-inline std::istream& getline (std::istream& is, std::string& str)
-{
-    std::istream& ist = getline( is, str, '\n' );
-    str.erase(remove(str.begin(), str.end(), '\r'), str.end());
-    return ist;
-    
+inline std::istream& getline(std::istream& is, std::string& str) {
+  std::istream& ist = std::getline(is, str, '\n');
+  str.erase(remove(str.begin(), str.end(), '\r'), str.end());
+  return ist;
 }
 
-}}
+}  // namespace tools
+}  // namespace votca
 
 #endif
