@@ -1,5 +1,5 @@
-/* 
- * Copyright 2009-2011 The VOTCA Development Team (http://www.votca.org)
+/*
+ * Copyright 2009-2019 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,16 +15,14 @@
  *
  */
 
-#ifndef _types_H
-#define	_types_H
+#ifndef _VOTCA_TOOLS_TYPES_H
+#define _VOTCA_TOOLS_TYPES_H
 
-namespace votca { namespace tools {
+#include <votca/tools/eigen.h>
+namespace votca {
 
-typedef unsigned char byte_t;
-typedef unsigned short word_t;
-typedef unsigned long dword_t;
+using Index = Eigen::Index;
 
-}}
-
-#endif	/* _types_H */
+}  // namespace votca
 
+#endif /* _types_H */
