@@ -1,5 +1,5 @@
-/* 
- * Copyright 2009-2011 The VOTCA Development Team (http://www.votca.org)
+/*
+ * Copyright 2009-2019 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,13 +16,14 @@
  */
 
 #ifndef _tools_version_H
-#define	_tools_version_H
+#define _tools_version_H
 
 #include <string>
 
-namespace votca { namespace tools {
-    const std::string & ToolsVersionStr();
-}}
-
-#endif	/* _tools_version_H */
+namespace votca {
+namespace tools {
+const std::string& ToolsVersionStr();
+}
+}  // namespace votca
 
+#endif /* _tools_version_H */
