@@ -1,5 +1,5 @@
-/* 
- * Copyright 2009-2011 The VOTCA Development Team (http://www.votca.org)
+/*
+ * Copyright 2009-2019 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,9 +17,9 @@
 
 #include <votca/tools/colors.h>
 
-namespace votca { namespace tools {
+namespace votca {
+namespace tools {
 
 Color<csDefault> DEFAULT_COLORS;
-
-}}
-
+}
+}  // namespace votca
