@@ -1,5 +1,5 @@
 /*
- * Copyright 2009-2019 The VOTCA Development Team (http://www.votca.org)
+ * Copyright 2009-2020 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -175,7 +175,7 @@ void Property::LoadFromXML(string filename) {
   XML_SetUserData(parser, (void *)&pstack);
   while (!fl.eof()) {
     string line;
-    getline(fl, line);
+    tools::getline(fl, line);
     line = line + "\n";
     if (line.length() > (size_t)std::numeric_limits<int>::max()) {
       throw std::runtime_error("Property::LoadFromXML: line is too long");
