@@ -1,5 +1,5 @@
 /*
- * Copyright 2009-2011 The VOTCA Development Team (http://www.votca.org)
+ * Copyright 2009-2019 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,9 +15,10 @@
  *
  */
 
-#include <stdexcept>
-#include "../../include/votca/tools/lexical_cast.h"
 #include "../../include/votca/tools/thread.h"
+#include "../../include/votca/tools/lexical_cast.h"
+#include <stdexcept>
+#include <votca/tools/types.h>
 
 using namespace std;
 
@@ -27,13 +28,13 @@ namespace tools {
 void *runwrapper(void *arg) {
   Thread *thread = (Thread *)(arg);
   thread->Run();
-  pthread_exit(NULL);
-  return NULL;
+  pthread_exit(nullptr);
+  return nullptr;
 }
 
-Thread::Thread() {}
+Thread::Thread() = default;
 
-Thread::~Thread() {}
+Thread::~Thread() = default;
 
 void Thread::Start() {
 
@@ -51,7 +52,7 @@ void Thread::Start() {
   pthread_attr_setdetachstate(&_attr, PTHREAD_CREATE_JOINABLE);
   _finished = false;
 
-  int rc =
+  Index rc =
       pthread_create(&_thread, &_attr, runwrapper, static_cast<void *>(this));
   if (rc) {
     throw std::runtime_error("ERROR; return code from pthread_create() is " +
@@ -61,7 +62,7 @@ void Thread::Start() {
 
 void Thread::WaitDone() {
   void *status;
-  int rc = pthread_join(_thread, &status);
+  Index rc = pthread_join(_thread, &status);
   if (rc) {
     throw std::runtime_error("ERROR; return code from pthread_join() is " +
                              boost::lexical_cast<std::string>(rc));
@@ -71,5 +72,5 @@ void Thread::WaitDone() {
 }
 
 bool Thread::IsFinished() const { return _finished; }
-}
-}
+}  // namespace tools
+}  // namespace votca
